==> sword_1.5.3.orig.tar.gz: sword-1.5.3.orig/apps/windoze/CBuilder4/BibleCS/vrslstfrm.cpp <==
//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "vrslstfrm.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TVerseListFrm *VerseListFrm;
//---------------------------------------------------------------------------
__fastcall TVerseListFrm::TVerseListFrm(TComponent* Owner, ListKey &iVerseList)
	: TForm(Owner), verseList(iVerseList) {
	pvrtf = new SWDispRTF(this);

	pvrtf->Parent = plPreview;
	pvrtf->Align = alClient;
	pvrtf->ScrollBars = ssVertical;
	pvrtf->ReadOnly = true;
}
//---------------------------------------------------------------------------

void __fastcall TVerseListFrm::ListBox1Click(TObject *Sender) {
	ModMap::iterator target;
	target = Form1->mainmgr->Modules.find(Form1->PageControl1->ActivePage->Caption.c_str());
	if (target != Form1->mainmgr->Modules.end()) {
		SWKey *savekey = *(*target).second;
		(*target).second->SetKey(ListBox1->Items->Strings[ListBox1->ItemIndex].c_str());
		pvrtf->Display(*(*target).second);
		(*target).second->SetKey(*savekey);
	}
}
//---------------------------------------------------------------------------

void __fastcall TVerseListFrm::ListBox1DblClick(TObject *Sender)
{
	Form1->DefaultVSKey = ListBox1->Items->Strings[ListBox1->ItemIndex].c_str();
	Form1->TextKeyChanged();
}
//---------------------------------------------------------------------------
void __fastcall TVerseListFrm::FormShow(TObject *Sender)
{
		for (verseList = TOP; (!verseList.Error()); verseList++)
			ListBox1->Items->Add((const char *)verseList);
}
//---------------------------------------------------------------------------

==> sword-1.5.6.tar.gz: sword-1.5.6/apps/windoze/CBuilder4/BibleCS/vrslstfrm.cpp <==
//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop

#include "vrslstfrm.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TVerseListFrm *VerseListFrm;
//---------------------------------------------------------------------------
__fastcall TVerseListFrm::TVerseListFrm(TComponent* Owner, ListKey &iVerseList)
	: TForm(Owner), verseList(iVerseList) {
	pvrtf = new SWDispRTF(this);

	pvrtf->Parent = plPreview;
	pvrtf->Align = alClient;
	pvrtf->ScrollBars = ssVertical;
	pvrtf->ReadOnly = true;
}
//---------------------------------------------------------------------------

void __fastcall TVerseListFrm::ListBox1Click(TObject *Sender) {
	ModMap::iterator target;
	target = Form1->mainmgr->Modules.find(Form1->PageControl1->ActivePage->Caption.c_str());
	if (target != Form1->mainmgr->Modules.end()) {
		SWKey *savekey = *(*target).second;
		(*target).second->setKey(ListBox1->Items->Strings[ListBox1->ItemIndex].c_str());
		pvrtf->Display(*(*target).second);
		(*target).second->SetKey(*savekey);
	}
}
//---------------------------------------------------------------------------

void __fastcall TVerseListFrm::ListBox1DblClick(TObject *Sender)
{
	Form1->DefaultVSKey = ListBox1->Items->Strings[ListBox1->ItemIndex].c_str();
	Form1->TextKeyChanged();
}
//---------------------------------------------------------------------------
void __fastcall TVerseListFrm::FormShow(TObject *Sender)
{
		for (verseList = TOP; (!verseList.Error()); verseList++)
			ListBox1->Items->Add((const char *)verseList);
}
//---------------------------------------------------------------------------
